function [incr] = diffAreaFun(r,delta)
% Return the increase in surface area of a sphere given a change in radius.
% r = original radius of the sphere in miles
% delta = change in radius in inches
% incr = increase in surface area in miles squared

newr= r + ((delta/12)/5280);  % new radius in miles
A= 4*pi*r^2;                  % original surface area
newA= 4*pi*newr^2;            % new surface area
incr= newA - A;
